@@ -1,10 +1,10 @@
 import datetime as dt
 import pandas as pd
-
+from googlewrapper.connect import Connection
 
 
 class GoogleSearchConsole:
-    def __init__(self, auth):
+    def __init__(self, auth = Connection().gsc()):
         self.auth = auth
         self._filter = None
         self._dims = ["page", "date"]
